@@ -1,6 +1,7 @@
-__author__ = """Arkadiusz Michał Ryś"""
-__email__ = "Arkadiusz.Michal.Rys@gmail.com"
-__version__ = "0.4.1"
+"""Custom python logging formatter with color output."""
+__version__ = "0.5.0"
+__version_info__ = tuple((int(num) if num.isdigit() else num for num in __version__.replace("-", ".", 1).split(".")))
+
 
 from arklog.logging import (
     CRITICAL,
@@ -18,6 +19,8 @@ from arklog.logging import (
     log,
     success,
     extra,
+    set_config_logging,
+    set_path_logging
 )
 
 from logging import (
